\name{knnz}
\alias{knnz}

\title{
k-th nearest neighbour autocovariate
}
\description{
The k-th nearest neighbour autovariate is defined between two classes which we
may denote by 0 and 1.
For a given observation, we find all the k-nearest neighbours, and sum
the number correspond to 1's and 0's.
Then take the difference and divide by k.
Symbolically,  
\deqn{\sum_{j in k_i} (I(y_j = 1) - I(y_j = 0))/k}
{sum {j in k_i} (I(y_j = 1) - I(y_j = 0))/k}
where eqn{k_i}{k_i} denotes the indicies of all observations
in the k-th neighbour of the i-th observation.

}

\usage{
knnz(k, X, Y, ...)
}

\arguments{
  \item{k}{

}
  \item{X}{
matrix of inputs of dimension n-by-p, where n is the number of samples and p is the
number of inputs or covariates.
}
  \item{Y}{
output variable, classes, contains K classes. 
}
  \item{\dots}{
optional arguments passed to knn.cv
}
}
\details{
later
}
\value{
vector of the kNN autocovariates
}

\references{
Holmes, C. C. and Adams, Niall M. (2003).  
Likelihood inference in nearest-neighbour classification models.
Biometrika 90, 99 - 112.
}

\author{
Shahidul M. Islam and A. I. McLeod
}

\note{
More later.
}

\seealso{
\code{\link{knnselect}}
}

\examples{
#A simple example
#The rows of the final result are re-arranged in order of distance
#from the (1,1) element, (750, 662), and the autocovariate is
#multipled by k.  So the first row of autocovariates can be checked
#by simply counting the the score going down the column labelled y.
X<-matrix(c(750, 662, 286, 519, 335, 574, 548, 505, 927, 267, 427, 
  452, 427, 711, 618, 311, 342, 426, 483, 302, 702, 
  1081, 963, 597, 567, 426, 822, 771, 571, 808, 973, 
  674, 906, 623, 1149, 357, 608, 836, 176, 849), byrow=TRUE, ncol=2)
y<-c(rep(-1,10),rep(1,10))
ks <- c(1, 3, 5, 7, 9, 11, 13)
Z<-matrix(numeric(length(ks)*20), nrow=20)
for (j in 1:length(ks)){
	k <- ks[j]
	z<-knnz(k, X=X, Y=y)*k
	cat(z, fill=TRUE)
	Z[,j]<-z
	}
Z<-cbind(X,y,Z)
dimnames(Z)<-list(1:20, c("x1","x2","y",paste("z",ks,sep="")))
d<-apply((Z[,1:2]-matrix(rep(Z[1,1:2],20),byrow=TRUE, ncol=2))^2, MARGIN=1, FUN=sum)
Z[order(d),]

}

\keyword{ classif } 
